@@ -38,7 +38,8 @@ except ImportError:
 from flent.build_info import VERSION
 from flent.testenv import TestEnvironment, TEST_PATH
 from flent.loggers import get_logger
-from flent.util import FuncAction, Update, keyval, keyval_int, ArgParser
+from flent.util import FuncAction, Update, keyval, keyval_int, ArgParser, \
+    token_split
 from flent.plotters import add_plotting_args
 from flent import loggers, util, resultset, runners
 
@@ -178,8 +179,8 @@ parser.add_argument(
 parser.add_argument(
     "-p", "--plot",
     action="store", type=unicode, dest="PLOT",
-    help="Select which plot to output for the given test (implies -f plot). "
-    "Use the --list-plots option to see available plots.")
+    help="Select which plot to output for the given test (implies -f plot if no"
+    "formatter is selected). Use the --list-plots option to see available plots.")
 
 parser.add_argument(
     "-t", "--title-extra",
@@ -568,7 +569,7 @@ class Settings(argparse.Namespace):
                 if isinstance(val, dict) and k in vals:
                     vals[k].update(val)
                 elif parser.is_list(k):
-                    vals[k] = [t(i.strip()) for i in v.split(",")]
+                    vals[k] = [t(i.strip()) for i in token_split(v)]
                 else:
                     vals[k] = val
 
@@ -700,7 +701,7 @@ class Settings(argparse.Namespace):
         if self.REMOTE_METADATA:
             self.EXTENDED_METADATA = True
 
-        if self.PLOT is not None:
+        if self.PLOT is not None and self.FORMAT == 'default':
             self.FORMAT = 'plot'
 
         if self.BATCH_REPS is not None:
