@@ -175,6 +175,8 @@ class Combiner(object):
             regexps.append(self.serial_regex)
         if self.filter_prefix:
             prefix = long_substr(filenames, prefix_only=True)
+            if "-" in prefix and not prefix.endswith("-"):
+                prefix = prefix[:prefix.rfind("-")+1]
             names = [n.replace(prefix, "", 1) for n in filenames]
         else:
             names = filenames
@@ -318,7 +320,7 @@ class SeriesCombiner(Combiner):
         new_results = []
 
         for s in self.orig_series:
-            res = ResultSet(TITLE=s['label'], NAME=self.orig_name)
+            res = ResultSet(TITLE=s.get('label'), NAME=self.orig_name)
             res.create_series(groups.keys())
             x = 0
             for d in zip_longest(*groups.values()):
@@ -344,7 +346,9 @@ class BothCombiner(Combiner):
     # second the series. Currently only works if there's just one series
     # name configured in the plot config.
     def group(self, groups, config):
-        assert len(config['series']) == 1
+        if len(config['series']) > 1:
+            raise RuntimeError("Cannot use group_by=both for plots with more "
+                               "than one data series")
         series_names = []
         group_names = []
         old_s = config['series'][0]
@@ -555,22 +559,24 @@ class RawReducer(Reducer):
 
         if data and self.cutoff is not None:
             start, end = self.cutoff
-            min_t = min((d['t'] for d in data))
+            min_t = min((d['t'] for d in data if 't' in d))
             start_t = min_t + start if start else min_t - 1
             if end is not None:
                 end_t = min_t + resultset.meta("TOTAL_LENGTH") - end
-                return [d for d in data if d['t'] > start_t and d['t'] < end_t]
+                return [d for d in data
+                        if 't' in d and d['t'] > start_t and d['t'] < end_t]
             else:
-                return [d for d in data if d['t'] > start_t]
+                return [d for d in data if 't' in d and d['t'] > start_t]
 
         return data
 
     def reduce(self, resultset, series, data=None):
         key = series['data']
-        if '::' in key:
+        if '::' in key and 'raw_key' not in series:
             key = key.split("::")[0]
+        raw_key = series.get("raw_key", "val")
         try:
-            rawdata = self._get_series(resultset, key)
+            rawdata = self._get_series(resultset, key, ensure=raw_key)
         except KeyError:
             return None
         if not rawdata and self.cutoff:
@@ -580,9 +586,9 @@ class RawReducer(Reducer):
             self.cutoff = (self.cutoff[0], None)
             rawdata = self._get_series(resultset, key)
         if self.filter_none:
-            data = [d['val'] for d in rawdata if d['val'] is not None]
+            data = [d[raw_key] for d in rawdata if d[raw_key] is not None]
         else:
-            data = [d['val'] for d in rawdata]
+            data = [d[raw_key] for d in rawdata]
         if not data:
             return None
         return self._reduce(data)
@@ -599,9 +605,14 @@ class RawSeqLossReducer(RawReducer):
         key = series['data']
         if '::' in key:
             key = key.split("::")[0]
+
+        smeta = resultset.meta('SERIES_META').get(key)
+        if smeta and 'PACKET_LOSS_RATE' in smeta and not self.cutoff:
+            return smeta['PACKET_LOSS_RATE']
+
         try:
             data = self._get_series(resultset, key, ensure='seq')
-            seqs = [d['seq'] for d in data]
+            seqs = [d['seq'] for d in data if not d.get('lost')]
 
             return 1 - len(seqs) / (max(seqs) - min(seqs) + 1)
         except (KeyError, ValueError):
@@ -612,8 +623,7 @@ class MosReducer(RawReducer):
     filter_none = False
     numpy_req = True
 
-    def reduce(self, resultset, series, data=None):
-        key = series['data']
+    def _calc_delay_loss(self, resultset, key):
         data = self._get_series(resultset, key)
         if not data:
             return None
@@ -623,16 +633,41 @@ class MosReducer(RawReducer):
         last_delay = -1
         last_seq = -1
         for d in data:
-            if last_seq > -1 and d['seq'] - last_seq > 1:
+            if d.get('lost'):
                 loss += 1
+                continue
+            if 'seq' not in d:
+                continue
+
+            if last_seq > -1 and d['seq'] - last_seq > 1:
+                loss += d['seq'] - last_seq - 1
+
             last_seq = d['seq']
-            if last_delay > -1:
-                jitter_samples.append(abs(last_delay - d['val']))
-            last_delay = d['val']
-            delay_samples.append(d['val'])
+            dval = d.get('owd_up', d['val'])
+            delay_samples.append(dval)
+
+            if 'ipdv_up' in d:
+                jitter_samples.append(abs(d['ipdv_up']))
+            elif last_delay > -1:
+                jitter_samples.append(abs(last_delay - dval))
+
+            last_delay = dval
 
         delay = np.mean(delay_samples) + 2 * np.mean(jitter_samples)
         lossrate = loss / len(data)
+
+        return delay, lossrate
+
+    def reduce(self, resultset, series, data=None):
+        key = series['data']
+
+        smeta = resultset.meta('SERIES_META').get(key)
+        if smeta and 'OWD_UP_MEAN' in smeta and not self.cutoff:
+            delay = smeta['OWD_UP_MEAN'] + 2 * smeta['IPDV_UP_MEAN']
+            lossrate = smeta['PACKET_LOSS_RATE']
+        else:
+            delay, lossrate = self._calc_delay_loss(resultset, key)
+
         mos = mos_score(delay, lossrate)
         return mos
 
