@@ -38,6 +38,7 @@ from argparse import SUPPRESS
 from datetime import datetime
 from itertools import chain
 from multiprocessing import Pool, Queue
+from distutils.version import LooseVersion
 
 from flent import util, batch, loggers, resultset, plotters
 from flent.build_info import DATA_DIR, VERSION
@@ -66,20 +67,13 @@ try:
 except NotImplementedError:
     CPU_COUNT = 1
 
+if plotters.MPL_VER < LooseVersion("1.4.2"):
+    raise RuntimeError("The GUI requires matplotlib version >= 1.4.2 to work.")
+else:
+    import matplotlib
+    matplotlib.use("Agg")
 
 FORCE_QT4 = bool(os.getenv("FORCE_QT4", False))
-try:
-    import matplotlib
-    ver = tuple([int(i) for i in matplotlib.__version__.split(".")[:2]])
-    if ver < (1, 4):
-        logger.warning("Forcing fallback to Qt4 because of old matplotlib v%s.",
-                       matplotlib.__version__)
-        FORCE_QT4 = True
-    matplotlib.use("Agg")
-except ImportError:
-    raise RuntimeError("The GUI requires matplotlib.")
-
-
 try:
     if FORCE_QT4:
         raise ImportError("Force fallback to Qt4")
@@ -2252,7 +2246,9 @@ class ResultWidget(get_ui_class("resultwidget.ui")):
             self.plotter.zoom(axis, direction)
 
     def update_settings(self, values):
-        if values['OVERRIDE_TITLE']:
+        if not self.results:
+            t = self.default_title
+        elif values['OVERRIDE_TITLE']:
             t = "%s - %s" % (self.results.meta('NAME'), values['OVERRIDE_TITLE'])
         else:
             t = self.results.title
