@@ -171,7 +171,8 @@ class CachingHandler(Handler):
 
     def replay(self, handler):
         for r in self.cache:
-            handler.handle(r)
+            if r.levelno >= handler.level:
+                handler.handle(r)
 
     def write(self, m):
         pass
@@ -230,7 +231,7 @@ def add_common_filters(handler):
     handler.addFilter(NamePrefixFilter("PyQt"))
 
 
-def setup_logfile(filename, level=DEBUG, maxlevel=None):
+def setup_logfile(filename, level=DEBUG, maxlevel=None, replay=True):
     if filename in logfiles:
         return
     logfiles.add(filename)
@@ -252,7 +253,7 @@ def setup_logfile(filename, level=DEBUG, maxlevel=None):
     logger.addHandler(handler)
     logger.setLevel(min(logger.level, level))
 
-    if cache_handler is not None:
+    if replay and cache_handler is not None:
         cache_handler.replay(handler)
 
     return handler
@@ -262,6 +263,7 @@ def remove_log_handler(handler):
     if not handler:
         return
 
+    handler.flush()
     logger = logging.getLogger()
     logger.removeHandler(handler)
 
