@@ -28,6 +28,7 @@ import gzip
 import io
 import os
 import re
+import shlex
 import socket
 import time
 
@@ -132,7 +133,7 @@ def diff_parts(strings, sep):
     a separator and pruning parts that are identical for all strings"""
 
     parts = [s.split(sep) for s in strings]
-    np = [p for p in zip(*parts) if len(set(p)) > 1]
+    np = [p for p in zip(*parts) if len(set(p)) >= 1]
 
     return [sep.join(p) for p in zip(*np)]
 
@@ -141,7 +142,7 @@ def is_executable(filename):
     return os.path.isfile(filename) and os.access(filename, os.X_OK)
 
 
-def which(executable, fail=False):
+def which(executable, fail=None):
     pathname, filename = os.path.split(executable)
     if pathname:
         if is_executable(executable):
@@ -158,7 +159,7 @@ def which(executable, fail=False):
                 logger.debug("which: %s is not an executable file", filename)
 
     if fail:
-        raise RuntimeError("No %s binary found in PATH." % executable)
+        raise fail("No %s binary found in PATH." % executable)
     return None
 
 
@@ -175,14 +176,19 @@ def path_components(path):
 
 
 def lookup_host(hostname, version=None):
+    logger.debug("Looking up hostname '%s'.", hostname)
     if version == 4:
         version = socket.AF_INET
     elif version == 6:
         version = socket.AF_INET6
     else:
         version = socket.AF_UNSPEC
-    hostnames = socket.getaddrinfo(hostname, None, version,
-                                   socket.SOCK_STREAM)
+    try:
+        hostnames = socket.getaddrinfo(hostname, None, version,
+                                       socket.SOCK_STREAM)
+    except Exception:
+        hostnames = None
+
     if not hostnames:
         raise RuntimeError("Found no hostnames on lookup of %s" % hostname)
 
@@ -485,12 +491,12 @@ def float_pair(value):
 
 def keyval(value):
     ret = {}
-    for p in value.split(";"):
+    for p in token_split(value, ";"):
         p = p.strip()
         if not p:
             continue
         try:
-            k, v = p.split('=', 1)
+            k, v = token_split(p, '=')
             ret.update({k.strip(): v.strip()})
         except ValueError:
             raise argparse.ArgumentTypeError(
@@ -507,11 +513,21 @@ def keyval_int(value):
 
 def comma_list(value):
     try:
-        return [v.strip() for v in value.split(",")]
+        return [v.strip() for v in token_split(value)]
     except ValueError:
         raise argparse.ArgumentTypeError("Unable to split into list.")
 
 
+def token_split(value, split_tokens=',;'):
+    """Split VALUE on the tokens given in SPLIT_TOKENS, while
+    avoiding splitting of quoted strings"""
+
+    lex = shlex.shlex(value, posix=True)
+    lex.whitespace_split = True
+    lex.whitespace = split_tokens
+    return list(lex)
+
+
 class ArgParam(object):
     """A class that takes an argparser and sets object properties from
     the argparser-defined parameters."""
